@@ -11,7 +11,7 @@ class TemplateTest < Haml::TestCase
     whitespace_handling    original_engine   list        helpful
     silent_script          tag_parsing       just_stuff  partials
     nuke_outer_whitespace  nuke_inner_whitespace         bemit
-    render_layout partial_layout partial_layout_erb}.freeze
+    render_layout partial_layout partial_layout_erb escape_safe_buffer}.freeze
 
   def setup
     @base = create_base
@@ -24,7 +24,7 @@ class TemplateTest < Haml::TestCase
     vars = { 'article' => Article.new, 'foo' => 'value one' }
 
     context = ActionView::LookupContext.new(TemplateTestHelper::TEMPLATE_PATH)
-    base = ActionView::Base.new(context, vars)
+    base = ActionView::Base.new(context, vars, nil)
 
     # This is needed by RJS in (at least) Rails 3
     base.instance_variable_set(:@template, base)
@@ -247,10 +247,6 @@ HAML
     assert_equal("<div data-html='&lt;foo&gt;bar&lt;/foo&gt;'></div>\n", render('%div{ "data-html" => "<foo>bar</foo>" }', :action_view))
   end
 
-  def test_xss_protection_in_attributes_with_safe_strings
-    assert_equal("<div data-html='<foo>bar</foo>'></div>\n", render('%div{ "data-html" => "<foo>bar</foo>".html_safe }', :action_view))
-  end
-
   def test_xss_protection_with_bang_in_interpolation
     assert_equal("Foo & Bar\n", render('! Foo #{"&"} Bar', :action_view))
   end
@@ -297,6 +293,16 @@ HAML
     assert_equal("Foo & Bar", render('- safe_concat "Foo & Bar"', :action_view))
   end
 
+  def test_annotated_template_names
+    original_setting = Haml::Plugin.annotate_rendered_view_with_filenames
+    Haml::Plugin.annotate_rendered_view_with_filenames = true
+    result = @base.render(partial: "partial")
+    assert_equal("<!-- BEGIN test/templates/_partial.haml -->\n", result.lines.first)
+    assert_equal("<!-- END test/templates/_partial.haml -->\n", result.lines.last)
+  ensure
+    Haml::Plugin.annotate_rendered_view_with_filenames = original_setting
+  end
+
   ## Regression
 
   def test_xss_protection_with_nested_haml_tag
