@@ -1,15 +1,9 @@
+# frozen_string_literal: true
+
 module TemplateTestHelper
   TEMPLATE_PATH = File.join(__dir__, "templates")
 end
 
-module Haml::Filters::Test
-  include Haml::Filters::Base
-
-  def render(text)
-    "TESTING HAHAHAHA!"
-  end
-end
-
 module Haml::Helpers
   def test_partial(name, locals = {})
     Haml::Engine.new(File.read(File.join(TemplateTestHelper::TEMPLATE_PATH, "_#{name}.haml")), Haml::Template.options).render(self, locals)
@@ -17,7 +11,7 @@ module Haml::Helpers
 end
 
 class Egocentic
-  def method_missing(*args)
+  def method_missing(*)
     self
   end
 end
