@@ -1,20 +1,9 @@
 # frozen_string_literal: true
 
-begin
-  if ENV['TRAVIS'] && RUBY_VERSION == '2.1.2' && !defined?(Rubinius)
-    require 'coveralls'
-    Coveralls.wear!
-  end
-rescue LoadError
-  # ignore error for other test Gemfiles
-end
+require "simplecov"
+SimpleCov.start
 
-if ENV["COVERAGE"]
-  require "simplecov"
-  SimpleCov.start
-end
-
-require 'bundler'
+require 'bundler/setup'
 require 'minitest/autorun'
 require 'action_pack'
 require 'action_controller'
@@ -32,6 +21,7 @@ class TestApp < Rails::Application
   config.eager_load = false
   config.root = ""
 end
+
 Rails.application = TestApp
 Rails.backtrace_cleaner.remove_silencers!
 
@@ -64,7 +54,7 @@ class Haml::TestCase < BASE_TEST_CLASS
   extend Declarative
 
   def render(text, options = {}, base = nil, &block)
-    scope  = options.delete(:scope)  || Object.new
+    scope = options.delete(:scope) || Object.new
     locals = options.delete(:locals) || {}
     engine = Haml::Engine.new(text, options)
     return engine.to_html(base) if base
@@ -102,7 +92,7 @@ class Haml::TestCase < BASE_TEST_CLASS
       def compiled_method_container
         self.class
       end
-    end.new(ActionView::LookupContext.new(''))
+    end.new(ActionView::LookupContext.new(''), {}, nil)
   end
 
   def self.error(*args)
